@@ -50,19 +50,19 @@ from boto.ec2.instance import Instance
 #from eutester import euvolume
 from eutester.euvolume import EuVolume
 from eutester import eulogger
-
+from eutester.taggedresource import TaggedResource
 from random import randint
 import sshconnection
 import os
 import re
 import time
-import re
-import eulogger
+import types
 
 
 
 
-class EuInstance(Instance):
+
+class EuInstance(Instance, TaggedResource):
     keypair = None
     keypath = None
     username = None
@@ -70,6 +70,8 @@ class EuInstance(Instance):
     rootfs_device = "sda"
     block_device_prefix = "sd"
     virtio_blk = False
+    bdm_vol = None
+    reservation = None
     attached_vols = []
     scsidevs = []
     ops = None
@@ -80,8 +82,14 @@ class EuInstance(Instance):
     retry = 1
     verbose = True
     ssh = None
+    private_addressing = False
     tester = None
-
+    laststate = None
+    laststatetime = None
+    age_at_state = None
+    cmdstart = 0
+    auto_connect = True
+    security_groups = []
 
    
     @classmethod
@@ -93,8 +101,12 @@ class EuInstance(Instance):
                                       keypath=None, 
                                       password=None, 
                                       username="root",  
+                                      auto_connect = True,
                                       verbose=True, 
                                       timeout=120,
+                                      private_addressing = False,
+                                      reservation = None, 
+                                      cmdstart=None, 
                                       retry=2
                                       ):
         '''
@@ -115,11 +127,16 @@ class EuInstance(Instance):
         
         newins.debugmethod = debugmethod
         if newins.debugmethod is None:
-            newins.logger = eulogger.Eulogger(identifier= str(instance.id) + "-" + str(instance.ip_address))
+            newins.logger = eulogger.Eulogger(identifier= str(instance.id))
             newins.debugmethod= newins.logger.log.debug
             
         if (keypair is not None):
-            keypath = os.getcwd() + "/" + keypair.name + ".pem" 
+            if isinstance(keypair,types.StringTypes):
+                keyname = keypair
+                keypair = tester.get_keypair(keyname)
+            else:
+                keyname = keypair.name
+            keypath = os.getcwd() + "/" + keyname + ".pem" 
         newins.keypair = keypair
         newins.keypath = keypath
         newins.password = password
@@ -128,16 +145,70 @@ class EuInstance(Instance):
         newins.attached_vols=[] 
         newins.timeout = timeout
         newins.retry = retry    
-        newins.connect_to_instance(timeout=timeout)
+        newins.private_addressing = private_addressing
+        newins.reservation = reservation or newins.tester.get_reservation_for_instance(newins)
+        newins.security_groups = newins.tester.get_instance_security_groups(newins)
+        newins.laststate = newins.state
+        newins.cmdstart = cmdstart
+        newins.auto_connect = auto_connect
+        newins.set_last_status()
         #newins.set_block_device_prefix()
-        newins.set_rootfs_device()
-        
+        if newins.root_device_type == 'ebs':
+            try:
+                volume = newins.tester.get_volume(volume_id = newins.block_device_mapping.current_value.volume_id)
+                newins.bdm_vol = EuVolume.make_euvol_from_vol(volume, tester=newins.tester,cmdstart=news.cmdstart)
+            except:pass
+                
+        if newins.auto_connect:
+            newins.connect_to_instance(timeout=timeout)
+        if newins.ssh:
+            newins.set_rootfs_device()
         return newins
     
+    def update(self):
+        super(EuInstance, self).update()
+        self.set_last_status()
+    
+    def set_last_status(self,status=None):
+        self.laststate = self.state
+        self.laststatetime = time.time()
+        self.age_at_state = self.tester.get_instance_time_launched(self)
+        #Also record age from user's perspective, ie when they issued the run instance request (if this is available)
+        if self.cmdstart:
+            self.age_from_run_cmd = "{0:.2f}".format(time.time() - self.cmdstart) 
+        else:
+            self.age_from_run_cmd = None
+        
+        
+    
+    def printself(self,title=True, footer=True, printmethod=None):
+        if self.bdm_vol:
+            bdmvol = self.bdm_vol.id
+        else:
+            bdmvol = None
+            
+        buf = "\n"
+        if title:
+            buf += str("-------------------------------------------------------------------------------------------------------------------------------------------------------------------\n")
+            buf += str('INST_ID').center(11)+'|'+str('EMI').center(13)+'|'+str('RES_ID').center(11)+'|'+str('LASTSTATE').center(10)+'|'+str('PRIV_ADDR').center(10)+'|'+str('AGE@STATUS').center(13)+'|'+str('VMTYPE').center(12)+'|'+str('BDM_VOL').center(13)+'|'+str('CLUSTER').center(25)+'|'+str('PUB_IP').center(16)+'|'+str('PRIV_IP')+'\n'
+            buf += str("-------------------------------------------------------------------------------------------------------------------------------------------------------------------\n")
+        buf += str(self.id).center(11)+'|'+str(self.image_id).center(13)+'|'+str(self.reservation.id).center(11)+'|'+str(self.laststate).center(10)+'|'+str(self.private_addressing).center(10)+'|'+str(self.age_at_state).center(13)+'|'+str(self.instance_type).center(12)+'|'+str(bdmvol).center(13)+'|'+str(self.placement).center(25)+'|'+str(self.public_dns_name).center(16)+'|'+str(self.private_ip_address).rstrip()
+        if footer:
+            buf += str("\n-------------------------------------------------------------------------------------------------------------------------------------------------------------------")
+        if printmethod:
+            printmethod(buf)
+        return buf
+        
+        
+        
+        
+    
     def reset_ssh_connection(self):
+        self.debug('reset_ssh_connection for:'+str(self.id))
         if ((self.keypath is not None) or ((self.username is not None)and(self.password is not None))):
             if self.ssh is not None:
                 self.ssh.close()
+            self.debug('Connecting ssh '+str(self.id))
             self.ssh = sshconnection.SshConnection(
                                                     self.public_dns_name, 
                                                     keypair=self.keypair, 
@@ -152,6 +223,7 @@ class EuInstance(Instance):
             self.debug("keypath or username/password need to be populated for ssh connection") 
             
     
+    
     def connect_to_instance(self, timeout=60):
         '''
         Attempts to connect to an instance via ssh.
@@ -167,9 +239,10 @@ class EuInstance(Instance):
             while (elapsed < timeout):
                 try:
                     self.reset_ssh_connection()
+                    self.debug('Try some sys...')
                     self.sys("")
                 except Exception, se:
-                    self.debug('Caught exception attempting to reconnect ssh'+ str(se))
+                    self.debug('Caught exception attempting to reconnect ssh:'+ str(se))
                     elapsed = int(time.time()-start)
                     self.debug('retrying ssh connection, elapsed:'+str(elapsed)+'/'+str(timeout))
                     time.sleep(5)
@@ -188,9 +261,8 @@ class EuInstance(Instance):
         '''
         if ( self.verbose is True ):
             self.debugmethod(msg)
-            
-                
-    def sys(self, cmd, verbose=True, timeout=120):
+
+    def sys(self, cmd, verbose=True, code=None, timeout=120):
         '''
         Issues a command against the ssh connection to this instance
         Returns a list of the lines from stdout+stderr as a result of the command
@@ -200,7 +272,7 @@ class EuInstance(Instance):
         '''
         output = []
         if (self.ssh is not None):
-            output = self.ssh.sys(cmd, verbose=verbose, timeout=timeout)
+            output = self.ssh.sys(cmd, verbose=verbose, code=code, timeout=timeout)
             return output
         else:
             raise Exception("Euinstance ssh connection is None")
@@ -317,6 +389,7 @@ class EuInstance(Instance):
         waitfordev - boolean to indicate whether or no to poll guest instance for local device to be removed
         optional - timeout - integer seconds to wait before timing out waiting for the volume to detach 
         '''
+
         start = time.time()
         elapsed = 0 
         for vol in self.attached_vols:
@@ -353,13 +426,13 @@ class EuInstance(Instance):
         raise Exception("Detach Volume("+str(euvolume.id)+") not found on ("+str(self.id)+")")
         return True
     
-    def get_metadata(self, element_path): 
+    def get_metadata(self, element_path, prefix='latest/meta-data/'): 
         """Return the lines of metadata from the element path provided"""
         ### If i can reach the metadata service ip use it to get metadata otherwise try the clc directly
         if self.found("ping -c 1 169.254.169.254", "1 received"):
-            return self.sys("curl http://169.254.169.254/latest/meta-data/" + element_path)
+            return self.sys("curl http://169.254.169.254/"+str(prefix)+str(element_path), code=0)
         else:
-            return self.sys("curl http://" + self.tester.get_ec2_ip()  + ":8773/latest/meta-data/" + element_path)
+            return self.sys("curl http://" + self.tester.get_ec2_ip()  + ":8773/"+str(prefix) + str(element_path), code=0)
         
     def set_block_device_prefix(self):
         return self.set_rootfs_device()
@@ -388,10 +461,13 @@ class EuInstance(Instance):
         else:
             self.rootfs_device = "sda"
             self.virtio_blk = False
+        
+    
     
     def terminate_and_verify(self,verify_vols=True,volto=30, timeout=300):
         '''
-        Attempts to terminate the instance and if flagged will attempt to verify the correct
+        Attempts to terminate the instance and verify delete on terminate state of an ebs root block dev if any. 
+        If flagged will attempt to verify the correct
         state of any volumes attached during the terminate operation. 
         
         :type verify_vols: boolean
@@ -405,6 +481,7 @@ class EuInstance(Instance):
         '''
         bad_vols = []
         bad_vol_ids = []
+        start = time.time()
         if verify_vols:
             self.debug('Checking euinstance attached volume state is in sync with clouds...')
             for vol in self.attached_vols:
@@ -415,12 +492,22 @@ class EuInstance(Instance):
                     bad_vols.append(vol)
                     bad_vol_ids.append(vol.id)
         self.tester.terminate_single_instance(self, timeout=timeout)
+        elapsed = int(time.time()-start)
+        if self.bdm_vol:
+            if self.block_device_mapping.current_value.delete_on_termination:
+                vol_state='deleted'
+            else:
+                vol_state='available'
+            self.bdm_vol.update()
+            while self.bdm_vol.status != vol_state and elapsed < timeout:
+                elapsed = int(time.time()-start)
+                self.debug('Delete on terminate:'+str(self.block_device_mapping.current_value.delete_on_termination)+', expected state:'+str(vol_state)+', '+str(self.bdm_vol.id)+" in state:"+str(self.bdm_vol.status)+", elapsed:"+str(elapsed)+"/"+str(timeout))
+                self.bdm_vol.update()
+                time.sleep(5)
         if verify_vols:
             for vol in self.attached_vols:
                 if vol in bad_vols:
                     continue
-                start = time.time()
-                elapsed = 0 
                 while (vol.status != 'available') and (elapsed < timeout):
                     time.sleep(5)
                     vol.update()
@@ -448,6 +535,8 @@ class EuInstance(Instance):
         optional - maxdevs - number use to specify the max device names to iterate over.Some virt envs have a limit of 16 devs. 
         '''
         d='e'
+        in_use_cloud = ""
+        in_use_guest = ""
         dev = None
         if prefix is None:
             prefix = self.block_device_prefix
@@ -462,11 +551,14 @@ class EuInstance(Instance):
             for avol in self.attached_vols:
                 if avol.clouddev == dev:
                     inuse = True
+                    in_use_guest += str(avol.id)+", "
                     continue
             #Check to see if the cloud has a conflict with this device name...
             for vol in cloudlist:
+                vol.update()
                 if (vol.attach_data is not None) and (vol.attach_data.device == dev):
                     inuse = True
+                    in_use_cloud += str(vol.id)+", "
                     continue
             if inuse is False:
                 self.debug("Instance:"+str(self.id)+" returning available scsi dev:"+str(dev))
@@ -475,7 +567,7 @@ class EuInstance(Instance):
                 d = chr(ord('e') + x) #increment the letter we append to the device string prefix
                 dev = None
         if dev is None:
-            raise Exception("Could not find a free scsi dev on instance:"+self.id )
+            raise Exception("Could not find a free scsi dev on instance:"+self.id+", maxdevs:"+str(maxdevs)+"\nCloud_devs:"+str(in_use_cloud)+"\nGuest_devs:"+str(in_use_guest))
         
     def zero_fill_volume(self,euvolume):
         '''
@@ -486,16 +578,23 @@ class EuInstance(Instance):
         fillcmd = "dd if=/dev/zero of="+str(voldev)+"; sync"
         return self.time_dd(fillcmd)
     
-    def random_fill_volume(self,euvolume,srcdev=None, length=0):
+    def random_fill_volume(self,euvolume,srcdev=None, length=None):
         '''
         Attempts to fill the entie given euvolume with unique non-zero data.
         The srcdev is read from in a set size, and then used to write to the euvolume to populate it. The file 
         helps with both speed up the copy in the urandom case, and adds both some level of randomness another src device as well as 
         allows smaller src devs to be used to fill larger euvolumes by repeatedly reading into the copy. 
-        returns dd's data/time stat
+        :param euvolume: the attached euvolume object to write data to
+        :param srcdev: the source device to copy data from 
+        :param length: the number of bytes to copy into the euvolume
+        :returns dd's data/time stat
         '''
         gb = 1073741824 
         fsize = 10485760 #10mb
+        if not euvolume in self.attached_vols:
+            raise Exception(self.id+" Did not find this in instance's attached list. Can not write to this euvolume")
+        if not length:
+            length = euvolume.size * gb
         voldev = euvolume.guestdev.strip()
         self.assertFilePresent(voldev)
         if srcdev is None:
@@ -506,11 +605,8 @@ class EuInstance(Instance):
                 srcdev = "/dev/"+str(self.sys("ls -1 /dev | grep 'da$'")[0]).strip()
                 fsize = randint(1048576,10485760)
                 
-        if length <= fsize:
-            fillcmd = self.sys("head -c "+str(length)+" "+srcdev+" > "+voldev+"; sync")
-        else:
-            count = int((euvolume.size*gb)/fsize)
-            fillcmd="head -c "+str(fsize)+" "+str(srcdev)+" > /tmp/datafile; x=0; while [ $x -lt "+str(count)+" ]; do cat /tmp/datafile; let x=$x+1; done | dd of="+str(voldev)+"; rm /tmp/datafile; sync"
+        fillcmd = "head -c "+str(length)+" "+srcdev+" > "+voldev+"; echo "+str(euvolume.id)+" > " + str(voldev)+"; sync"
+
         return self.time_dd(fillcmd)
     
     
@@ -523,7 +619,7 @@ class EuInstance(Instance):
         for line in out:
             line = str(line)
             if re.search('copied',line):
-                time=int(str(line.split(',').pop()).split()[0])
+                time=float(str(line.split(',').pop()).split()[0])
         return time
     
     def vol_write_random_data_get_md5(self, euvolume, srcdev=None, length=32, timepergig=90, overwrite=False):
@@ -542,7 +638,8 @@ class EuInstance(Instance):
         #check to see if there's existing data that we should avoid overwriting 
         if overwrite or ( int(self.sys('head -c 32 '+str(voldev)+' | xargs -0 printf %s | wc -c')[0]) == 0):
             self.random_fill_volume(euvolume, srcdev=srcdev, length=length)
-        self.debug("Volume has existing data, skipping random data fill")
+        else:
+            self.debug("Volume has existing data, skipping random data fill")
         #calculate checksum of euvolume attached device for given length
         md5 = self.md5_attached_euvolume(euvolume, timepergig=timepergig,length=length)
         self.debug("Filled Volume:"+euvolume.id+" dev:"+voldev+" md5:"+md5)
@@ -574,15 +671,15 @@ class EuInstance(Instance):
             raise Exception("Failed to md5 attached volume: " +str(e))
         return md5
     
-    def get_dev_md5(self, devpath, length): 
+    def get_dev_md5(self, devpath, length, timeout=60): 
         self.assertFilePresent(devpath)
         if length == 0:
-            md5 = str(self.sys("md5sum "+voldev, timeout=timeout)[0]).split(' ')[0].strip()
+            md5 = str(self.sys("md5sum "+devpath, timeout=timeout)[0]).split(' ')[0].strip()
         else:
             md5 = str(self.sys("head -c "+str(length)+" "+str(devpath)+" | md5sum")[0]).split(' ')[0].strip()
         return md5
         
-    def reboot_instance_and_verify(self,waitconnect=30, timeout=300, connect=True, checkvolstatus=False):
+    def reboot_instance_and_verify(self,waitconnect=30, timeout=300, connect=True, checkvolstatus=False, pad=5):
         '''
         Attempts to reboot an instance and verify it's state post reboot. 
         waitconnect-optional-integer representing seconds to wait before attempting to connect to instance after reboot
@@ -592,6 +689,9 @@ class EuInstance(Instance):
         '''
         msg=""
         self.debug('Attempting to reboot instance:'+str(self.id))
+        uptime = int(self.sys('cat /proc/uptime')[0].split()[1].split('.')[0])
+        elapsed = 0
+        start = time.time()
         if checkvolstatus:
             #update the md5sums per volume before reboot
             bad_vols=self.get_unsynced_volumes()
@@ -602,6 +702,11 @@ class EuInstance(Instance):
         self.reboot()
         time.sleep(waitconnect)
         self.connect_to_instance(timeout=timeout)
+        elapsed = int(time.time()-start)
+        newuptime = int(self.sys('cat /proc/uptime')[0].split()[1].split('.')[0])
+        #Check to see if new uptime is at least 'pad' less than before, allowing for some pad 
+        if (newuptime - (uptime+elapsed)) > pad:
+            raise Exception("Instance uptime does not represent a reboot. Orig:"+str(uptime)+", New:"+str(newuptime)+", elapsed:"+str(elapsed))
         if checkvolstatus:
             badvols= self.get_unsynced_volumes()
             if badvols != []:
@@ -635,7 +740,7 @@ class EuInstance(Instance):
         
     def get_unsynced_volumes(self,euvol_list=None, md5length=32, timepervol=90,min_polls=2, check_md5=False):
         '''
-        Returns list of volumes which are:
+        Description: Returns list of volumes which are:
         -in a state the cloud believes the vol is no longer attached
         -the attached device has changed, or is not found.
         If all euvols are shown as attached to this instance, and the last known local dev is present and/or a local device is found with matching md5 checksum
@@ -644,11 +749,11 @@ class EuInstance(Instance):
         A subset can be provided in the list argument 'euvol_list'. 
         Returns a list of euvolumes for which a corresponding guest device could not be found, or the cloud no longer believes is attached. 
          
-        euvol_list - optional - euvolume object list. Defaults to all self.attached_vols
-        md5length - optional - defaults to the length given in each euvolume. Used to calc md5 checksum of devices
-        timerpervolume -optional - time to wait for device to appear, per volume before failing
-        min_polls - optional - minimum iterations to check guest devs before failing, despite timeout
-        check_md5 - optional - find devices by md5 comparision. Default is to only perform this check when virtio_blk is in use.
+        :param euvol_list: - optional - euvolume object list. Defaults to all self.attached_vols
+        :param md5length: - optional - defaults to the length given in each euvolume. Used to calc md5 checksum of devices
+        :param timerpervolume: -optional - time to wait for device to appear, per volume before failing
+        :param min_polls: - optional - minimum iterations to check guest devs before failing, despite timeout
+        :param check_md5: - optional - find devices by md5 comparision. Default is to only perform this check when virtio_blk is in use.
         '''
         bad_list = []
         vol_list = []
@@ -661,16 +766,17 @@ class EuInstance(Instance):
             vol_list.append(euvol_list)
         else:
             vol_list = self.attached_vols
-        
-            
+        self.debug("Checking for volumes whos state is not in sync with our instance's test state...")
         for vol in vol_list:
             #first see if the cloud believes this volume is still attached. 
             try: 
                 self.debug("Checking volume:"+str(vol.id))
                 if (vol.attach_data.instance_id == self.id): #verify the cloud status is still attached to this instance
+                    self.debug("Cloud beleives volume:"+str(vol.id)+" is attached to:"+str(self.id)+", check for guest dev...")
                     found = False
                     elapsed = 0 
                     start = time.time()
+                    checked_vdevs = []
                     #loop here for timepervol in case were waiting for a volume to appear in the guest. ie attaching
                     while (not found) and ((elapsed <= timepervol) or (poll_count < min_polls)):
                         try:
@@ -678,6 +784,7 @@ class EuInstance(Instance):
                             #Ugly... :-(
                             #handle virtio and non virtio cases differently (KVM case needs improvement here).
                             if self.virtio_blk or check_md5:
+                                self.debug('Checking any new devs for md5:'+str(vol.md5))
                                 #Do some detective work to see what device name the previously attached volume is using
                                 devlist = self.get_dev_dir()
                                 for vdev in devlist:
@@ -762,7 +869,7 @@ class EuInstance(Instance):
         for vol in cloudlist:
             #check to see if the volume is attached to us, but is not involved with the bdm for this instance
             found = False
-            if (vol.attach_data.instance_id == self.id) and not ( self.root_device_type == 'ebs' and self.block_device_mapping.current_name != vol.attach_data.device):
+            if (vol.attach_data.instance_id == self.id) and not ( self.root_device_type == 'ebs' and self.bdm_vol.id != vol.id):
                 for avol in self.attached_vols:
                     if avol.id == vol.id:
                         self.debug("Volume"+vol.id+" found attached")
@@ -785,6 +892,7 @@ class EuInstance(Instance):
                         if reattach:
                             dev = self.get_free_scsi_dev()
                             self.attach_volume(self, self, vol,dev )
+            
                     
                 
         
