@@ -57,8 +57,46 @@ Sample:
 
 '''
 import types
+import re
 
-class EucaProperties():
+class Euproperty_type():
+    authentication = 'authentication'
+    bootstrap = 'bootstrap'
+    cloud = 'cloud'
+    cluster = 'cluster'
+    reporting = 'reporting'
+    storage = 'storage'
+    system = 'system'
+    vmwarebroker = 'vmwarebroker'
+    walrus = 'walrus'
+    www = 'www'
+    
+    @classmethod
+    def get_type_by_string(cls,str):
+        try:
+            return getattr(self, str)
+        except AttributeError, ae:
+            self.debug('Property type:'+str(str)+" not defined, new property type?")
+            raise ae
+            
+class Euproperty():
+    def __init__(self, prop_mgr, property_string, servicetype,  partition, name, value, mandatory=False):
+        self.prop_mgr = prop_mgr
+        self.servicetype = Euproperty_type.get_type_by_string(servicetype)
+        self.partition = partition
+        self.name = name
+        self.value = value
+        self.property_string = str(servicetype)+"."+str(partition)+"."+str(name)
+        self.utils = Euproperty_utils()
+        self.utils = prop_mgr
+        self.lastvalue = value
+        self.mandatory=mandatory
+        
+    def update(self):
+        self.propmgr.update_property_list()
+    
+    
+class Euproperty_manager():
     tester = None
     verbose = False
     debugmethod = None
@@ -68,6 +106,12 @@ class EucaProperties():
         self.debugmethod = debugmethod
         self.verbose = verbose
         self.clc = self.get_clc()
+        self.access_key = self.tester.aws_access_key_id
+        self.secret_key = self.tester.aws_secret_access_key
+        self.service_url = 'http://'+str(self.tester.get_ec2_ip())+':8773/services/Eucalytpus'
+        self.cmdpath = self.tester.eucapath+'/usr/sbin/'
+        self.properties = []
+        
         
     def get_clc(self):
         return self.tester.service_manager.get_enabled_clc().machine   
@@ -83,24 +127,70 @@ class EucaProperties():
                 print (str(msg))
             else:
                 self.debugmethod(msg)
-             
+    
+         
             
-    def get_property(self, prop):
+    def get_property_value(self, prop):
         '''
         Returns a tuple containing the current property value plus the property string. 
         prop - mandatory - string representing the property to fetch. 
         ecuaops -optional - the eucaops/eutester object to fetch the property from
-        '''
+        
         self.debug("Getting property:"+prop)
-        eucaops = self.tester
-        prop_string = clc.sys('euca-describe-properties | grep ' + prop, code=0)
+        prop_string = self.clc.sys(self.cmdpath+'euca-describe-properties -U '+str(self.service_url)+' -I '+str(self.access_key)+' -S '+ str(self.secret_key) +' | grep ' + prop, code=0)
         if (prop_string != []):
             value = str(prop_string[0]).split()[2]
         else:
             raise EuPropertiesException("describe properties returned null for "+prop)
-        return value,prop
-    
-    
+        '''
+        prop = self.get_euproperty_by_name(prop)
+        return prop.value
+        
+    def update_property_list(self):
+        newlist = []
+        self.debug("Getting property list...")
+        cmdout = self.clc.sys(self.cmdpath+'euca-describe-properties -U '+str(self.service_url)+' -I '+str(self.access_key)+' -S '+ str(self.secret_key) +' | grep PROPERTY', code=0)
+        for propstring in cmdout:
+            newlist.append(parse_euproperty_from_string(propstring))
+        self.properties = newlist
+        
+                
+    def parse_euproperty_from_string(self, str):
+        '''
+        Intended to convert a line of ouptut from euca-describe-properties into
+        a euproperty. 
+        :param str: line of output, example: "PROPERTY    walrus.storagemaxbucketsizeinmb    5120"
+        :returns euproperty
+        '''
+        toss, ret_property_string, ret_value = str.split()
+        for prop in self.properties:
+            #if this property is in our list, update the value and return
+            if prop.property_string == ret_property_string:
+                prop.lastvalue = prop.value
+                prop.value = ret_value
+                return prop
+        #else this property is not in our list yet, create a new property
+        propattrs = ret_property_string.split('.')
+        try:
+            ret_type = Euproperty_type.get_type_by_string(propattrs[0])
+            propattrs.remove(propattrs[0])
+        except AttributeError:
+            ret_servicetype = Euproperty_type.get_type_by_string(propatters[1])
+            ret_partition = propatters[0]
+            propattrs.remove(propattrs[0])
+            propattrs.remove(propattrs[1])
+        ret_name = str(".").join(propattrs)
+        newprop = Euproperty(self, ret_property_string, ret_servicetype,  ret_partition, ret_name, ret_value)
+        self.properties.append(newprop)
+            
+        
+    def get_euproperty_by_name(self,name):
+        for prop in self.properties:
+            if prop.name == name:
+                return prop
+        raise Exception('Property not found by name:'+str(name))
+        
+        
     def set_property(self,  prop, value):
         '''
         Sets the property 'prop' at eucaops/eutester object 'tester' to 'value'    
@@ -112,7 +202,7 @@ class EucaProperties():
         value = str(value)
         eucaops = self.tester
         self.debug('Setting property('+prop+') to value:'+str(value))
-        ret_string = clc.sys('euca-modify-property -p '+prop+'='+str(value), code=0)
+        ret_string = self.clc.sys(self.cmdpath+'euca-modify-property -U '+str(self.service_url)+' -I '+str(self.access_key)+' -S '+ str(self.secret_key) +' -p '+prop+'='+str(value), code=0)
         if ( ret_string != [] ):
             ret_value= str(ret_string[0]).split()[2]
         else:
@@ -120,7 +210,6 @@ class EucaProperties():
         
         if (ret_value != value):
             raise EuPropertiesException("set property("+prop+") to value("+str(value)+") failed.Ret Value ("+str(ret_value)+")\nRet String\n"+ret_string)
-        
         return ret_value
         
     def reset_property_to_default(self, prop):
@@ -132,7 +221,7 @@ class EucaProperties():
         '''
     
         eucaops = self.tester
-        ret_string = str(clc.sys('euca-modify-property -r '+prop,code=0)[0])
+        ret_string = str(self.clc.sys(self.cmdpath+'euca-modify-property -U '+str(self.service_url)+' -I '+str(self.access_key)+' -S '+ str(self.secret_key) +' -r '+prop,code=0)[0])
         ret_value= ret_string.split()[2]
         self.debug('Reset property('+prop+') to default value('+str(ret_value)+')')
         return ret_value
@@ -147,7 +236,7 @@ class EucaProperties():
         if (ireadthewarning is False):
             raise EuPropertiesException("ireadthewarning is set to false in get_property_default_value")
     
-        original = self.get_property(prop)[0]
+        original = self.get_property_value(prop)
         default = self.reset_property_to_default(prop)
         self.set_property(prop, original)
         return default
@@ -163,7 +252,7 @@ class EucaProperties():
           
     #PARTI00.storage.maxvolumesizeingb
     def get_storage_maxvolumesizeingb(self,  zone='PARTI00'):
-        value = self.get_property(  zone+'.storage.maxvolumesizeingb')
+        value = self.get_property_value(  zone+'.storage.maxvolumesizeingb')
         return value
     
     def set_storage_maxvolumesizeingb(self, value, zone='PARTI00'):
@@ -171,7 +260,7 @@ class EucaProperties():
     
     #PARTI00.storage.maxtotalvolumesizeingb 
     def get_storage_maxtotalvolumesizeingb(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.maxtotalvolumesizeingb')
+        value = self.get_property_value(  zone+'.storage.maxtotalvolumesizeingb')
         return value
     
     def set_storage_maxtotalvolumesizeingb(self, value,  zone='PARTI00'):
@@ -180,7 +269,7 @@ class EucaProperties():
     
     #PARTI00.storage.zerofillvolumes 
     def get_storage_zerofillvolumes(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.zerofillvolumes')
+        value = self.get_property_value(  zone+'.storage.zerofillvolumes')
         return value
     
     def set_storage_zerofillvolumes(self, value,  zone='PARTI00'):
@@ -188,7 +277,7 @@ class EucaProperties():
         
     #PARTI00.storage.volumesdir 
     def get_storage_volumesdir(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.volumesdir')
+        value = self.get_property_value(  zone+'.storage.volumesdir')
         return value
     
     def set_storage_volumesdir(self, value,  zone='PARTI00'):
@@ -196,7 +285,7 @@ class EucaProperties():
         
     #PARTI00.storage.tid
     def get_storage_tid(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.tid')
+        value = self.get_property_value(  zone+'.storage.tid')
         return value
     
     def set_storage_tid(self, value,  zone='PARTI00'):
@@ -204,15 +293,15 @@ class EucaProperties():
     
     #PARTI00.storage.storeprefix
     def get_storage_storeprefix(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.storeprefix')
+        value = self.get_property_value(  zone+'.storage.storeprefix')
         return value
     
     def set_storage_storeprefix(self, value,  zone='PARTI00'):
         return self.set_property(  zone+'.storage.storeprefix', value)
     
-    #PARTI00.storage.storageinterface
+    #PARTI00.storageinterface
     def get_storageinterface(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.storageinterface')
+        value = self.get_property_value(  zone+'.storage.storageinterface')
         return value
     
     def set_storageinterface(self, value,  zone='PARTI00'):
@@ -220,7 +309,7 @@ class EucaProperties():
     
     #PARTI00.storage.snappercent
     def get_storage_snappercent(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.snappercent')
+        value = self.get_property_value(  zone+'.storage.snappercent')
         return value
     
     def set_storage_snappercent(self, value,  zone='PARTI00'):
@@ -228,7 +317,7 @@ class EucaProperties():
         
     #PARTI00.storage.shouldtransfersnapshots
     def get_storage_shouldtransfersnapshots(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.shouldtransfersnapshots')
+        value = self.get_property_value(  zone+'.storage.shouldtransfersnapshots')
         return value
     
     def set_storage_shouldtransfersnapshots(self, value,  zone='PARTI00'):
@@ -236,7 +325,7 @@ class EucaProperties():
         
     #PARTI00.storage.sanuser
     def get_storage_sanuser(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.sanuser')
+        value = self.get_property_value(  zone+'.storage.sanuser')
         return value
     
     def set_storage_sanuser(self, value,  zone='PARTI00'):
@@ -244,7 +333,7 @@ class EucaProperties():
     
     #PARTI00.storage.sanpassword
     def get_storage_sanpassword(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.sanpassword')
+        value = self.get_property_value(  zone+'.storage.sanpassword')
         return value
     
     def set_storage_sanpassword(self, value,  zone='PARTI00'):
@@ -252,7 +341,7 @@ class EucaProperties():
         
     #PARTI00.storage.sanhost
     def get_storage_sanhost(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.sanhost')
+        value = self.get_property_value(  zone+'.storage.sanhost')
         return value
     
     def set_storage_sanhost(self, value,  zone='PARTI00'):
@@ -260,7 +349,7 @@ class EucaProperties():
         
     #PARTI00.storage.minornumber
     def get_storage_minornumber(self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.minornumber')
+        value = self.get_property_value(  zone+'.storage.minornumber')
         return value
     
     def set_storage_minornumber(self, value,  zone='PARTI00'):
@@ -268,7 +357,7 @@ class EucaProperties():
     
     #PARTI00.storage.majornumber 
     def get_storage_majornumber (self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.majornumber ')
+        value = self.get_property_value(  zone+'.storage.majornumber ')
         return value
     
     def set_storage_majornumber (self, value,  zone='PARTI00'):
@@ -276,7 +365,7 @@ class EucaProperties():
         
     #PARTI00.storage.dasdevice 
     def get_storage_dasdevice (self,   zone='PARTI00'): 
-        value = self.get_property(  zone+'.storage.dasdevice')
+        value = self.get_property_value(  zone+'.storage.dasdevice')
         return value
     
     def set_storage_dasdevice (self, value,  zone='PARTI00'):
@@ -285,7 +374,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.dasdevice ', value)
         
     def get_storage_activestoragegroupcleaning(self, zone='PARTI00'): #false
-        return self.get_property(  zone+'.storage.activestoragegroupcleaning')
+        return self.get_property_value(  zone+'.storage.activestoragegroupcleaning')
     
     def set_storage_activestoragegroupcleaning(self, boolean,  zone='PARTI00'):
         if not isinstance(boolean, types.BooleanType):
@@ -293,7 +382,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.activestoragegroupcleaning', boolean) 
     
     def get_storage_chapuser(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.chapuser')
+        return self.get_property_value(  zone+'.storage.chapuser')
     
     def set_storage_chapuser(self, string,  zone='PARTI00'):    #e4c6-1000
         if not isinstance(string, types.StringTypes):
@@ -301,7 +390,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.chapuser')
     
     def get_storage_blockstoragemanager(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.blockstoragemanager')
+        return self.get_property_value(  zone+'.storage.blockstoragemanager')
     
     def set_storage_blockstoragemanager(self, string,  zone='PARTI00'):    #e4c6-1000
         if not isinstance(string, types.StringTypes):
@@ -309,7 +398,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.blockstoragemanager')
     
     def get_storage_clipath(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.clipath')
+        return self.get_property_value(  zone+'.storage.clipath')
     
     def set_storage_clipath(self, path,  zone='PARTI00'):    #/opt/Navisphere/bin/naviseccli
         if not isinstance(path, types.StringTypes):
@@ -317,7 +406,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.clipath')
         
     def get_storage_clonestoragegroup(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.clonestoragegroup')
+        return self.get_property_value(  zone+'.storage.clonestoragegroup')
    
     def set_storage_clonestoragegroup(self, string,  zone='PARTI00'):    #eucalyptus_clonelungroup
         if not isinstance(string, types.StringTypes):
@@ -325,7 +414,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.clonestoragegroup')
         
     def get_storage_loginscope(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.loginscope')
+        return self.get_property_value(  zone+'.storage.loginscope')
     
     def set_storage_loginscope(self, int,  zone='PARTI00'):    #0
         if not isinstance(int, types.IntType):
@@ -333,7 +422,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.loginscope')
         
     def get_storage_lunspallocator(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.lunspallocator')
+        return self.get_property_value(  zone+'.storage.lunspallocator')
     
     def set_storage_lunspallocator(self, string,  zone='PARTI00'):    #EmcVnxLunSpAllocatorByVolIdHash
         if not isinstance(string, types.StringTypes):
@@ -341,7 +430,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.lunspallocator')
         
     def get_storage_ncpaths(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.ncpaths')
+        return self.get_property_value(  zone+'.storage.ncpaths')
     
     def set_storage_ncpaths(self, string,  zone='PARTI00'):    #iface0:192.168.25.182,iface1:10.109.25.186
         if not isinstance(string, types.StringTypes):
@@ -349,7 +438,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.ncpaths')
         
     def get_storage_quiescetimeseconds(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.quiescetimeseconds')
+        return self.get_property_value(  zone+'.storage.quiescetimeseconds')
     
     def set_storage_quiescetimeseconds(self, int,  zone='PARTI00'):    #10
         if not isinstance(int, types.IntType):
@@ -357,7 +446,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.quiescetimeseconds')
         
     def get_storage_scpaths(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.scpaths')
+        return self.get_property_value(  zone+'.storage.scpaths')
     
     def set_storage_scpaths(self, string,  zone='PARTI00'):    #iface0:192.168.25.182,iface1:10.109.25.186
         if not isinstance(string, types.StringTypes):
@@ -365,7 +454,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.scpaths')
         
     def get_storage_storagepool(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.storagepool')
+        return self.get_property_value(  zone+'.storage.storagepool')
     
     def set_storage_storagepool(self, int,  zone='PARTI00'):    #0
         if not isinstance(int, types.IntType):
@@ -373,7 +462,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.storagepool')
         
     def get_storage_syncrate(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.syncrate')
+        return self.get_property_value(  zone+'.storage.syncrate')
     
     def set_storage_syncrate(self, string,  zone='PARTI00'):    #high
         if not isinstance(string, types.StringTypes):
@@ -381,7 +470,7 @@ class EucaProperties():
         return self.set_property(  zone+'.storage.syncrate')
         
     def get_storage_timeoutinmillis(self, zone='PARTI00'):
-        return self.get_property(  zone+'.storage.storage.timeoutinmillis')
+        return self.get_property_value(  zone+'.storage.timeoutinmillis')
    
     def set_storage_timeoutinmillis(self, int,  zone='PARTI00'):    #<unset
         if not isinstance(int, types.IntType):
@@ -395,7 +484,7 @@ class EucaProperties():
     '''
     #walrus.storagemaxtotalsnapshotsizeingb 
     def get_walrus_storagemaxtotalsnapshotsizeingb(self, tester=None):
-        value = self.get_property(  'walrus.storagemaxtotalsnapshotsizeingb')
+        value = self.get_property_value(  'walrus.storagemaxtotalsnapshotsizeingb')
         return value
     def set_walrus_storagemaxtotalsnapshotsizeingb(self, value, tester=None):
         return self.set_property(  'walrus.storagemaxtotalsnapshotsizeingb', value)
