@@ -326,7 +326,11 @@ class EutesterTestCase(unittest.TestCase):
                    configblocks=True,
                    ignoreblocks=True,
                    color=True,
-                   testlist=True):
+                   testlist=True,
+                   userdata=True,
+                   instance_user=True,
+                   instance_password=True,
+                   region=True):
         '''
         Description: Convenience method to setup argparse parser and some canned default arguments, based
         upon the boolean values provided. For each item marked as 'True' this method will add pre-defined 
@@ -374,6 +378,15 @@ class EutesterTestCase(unittest.TestCase):
         :type testlist: string list
         :param testlist: Flag to present the testlist command line argument/option for providing a list of testnames to run
         
+        :type userdata: boolean
+        :param userdata: Flag to present the userdata command line argument/option for providing userdata to instance(s) within test
+        
+        :type instance_user: boolean
+        :param instance_user: Flag to present the instance_user command line argument/option for providing an ssh username for instance login via the cli
+        
+        :type instance_password: boolean
+        :param instance_password: Flag to present the instance_password command line argument/option for providing a ssh password for instance login via the cli
+        
         :type use_color: flag
         :param use_color: Flag to enable/disable use of ascci color codes in debug output. 
         '''
@@ -392,10 +405,10 @@ class EutesterTestCase(unittest.TestCase):
                                 help="path to credentials", default=None)
         if password:
             parser.add_argument('--password', 
-                                help="password to use for machine root ssh access", default='foobar')
+                                help="password to use for machine root ssh access", default=None)
         if config:
             parser.add_argument('--config',
-                                help='path to config file', default='../input/2b_tested.lst')   
+                                help='path to config file', default=None)
         if configblocks:
             parser.add_argument('--configblocks', nargs='+',
                                 help="Config sections/blocks in config file to read in", default=[])
@@ -414,7 +427,19 @@ class EutesterTestCase(unittest.TestCase):
         if vmtype:
             parser.add_argument('--vmtype',
                                 help="Virtual Machine Type to use in this test", default='c1.medium')
-        if color: 
+        if userdata:
+            parser.add_argument('--userdata',
+                                help="User data string to provide instance run within this test", default=None)
+        if instance_user:
+            parser.add_argument('--instance_user',
+                                help="Username used for ssh login. Default:'root'", default='root')
+        if instance_password:
+            parser.add_argument('--instance_passsword',
+                                help="Password used for ssh login. When value is 'None' ssh keypair will be used and not username/password, default:'None'", default=None)
+        if region:
+            parser.add_argument('--region',
+                help="Use AWS region instead of Eucalyptus", default=None)
+        if color:
             parser.add_argument('--use_color', dest='use_color', action='store_true', default=False)
         self.parser = parser  
         return parser
@@ -580,7 +605,7 @@ class EutesterTestCase(unittest.TestCase):
         self.status(msg, traceback=3,testcolor=TestColor.get_canned_color('whiteonblue'))
         
     def endsuccess(self,msg=""):
-        msg = "- SUCCESS ENDED - " + msg
+        msg = "- UNIT ENDED - " + msg
         self.status(msg, traceback=2,a=1, testcolor=TestColor.get_canned_color('whiteongreen'))
       
     def endfailure(self,msg="" ):
@@ -685,6 +710,7 @@ class EutesterTestCase(unittest.TestCase):
                         self.endfailure(str(test.name))
                 else:
                     self.endsuccess(str(test.name))
+                self.debug(self.print_test_list_short_stats(list))
                         
         finally:
             elapsed = int(time.time()-start)
